import re


def remove_rich_tag(text):
    """remove rich styling from a string"""
    pattern = r"\[[^\]]*\](.*?)\[/\]"
    return re.sub(pattern, r"\1", text)


def advance_enum_val(enum_type, cur_val):
    """advance a value in an enum by one, wrapping around"""
    members = [str(e.value) for e in enum_type]
    cur_idx = members.index(remove_rich_tag(cur_val))
    next_idx = (cur_idx + 1) % len(members)
    return members[next_idx]


def get_colored_status(status: str) -> str:
    colors = {
        "zero": "#666666",
        "wip": "#33aa99",
        "blocked": "#cc9900",
        "done": "#009900",
    }
    return f"[{colors[status]}]{status}[/]"


def get_colored_category(category: str) -> str:
    hash_val = sum(ord(c) for c in category)
    hue = hash_val % 360
    color = f"rgb({hue},200,200) on default"
    return f"[{color}]{category}[/]"
